@@ -20,13 +20,13 @@ cargo metadata --format-version 1 --no-deps \
 	done
 
 (cd web && npx npm-check-updates -u && npm update)
+(cd telegram-bot && npx npm-check-updates -u && npm update)
 
 current_wix="$(jq -r .tools.wix.version < windows-wix/.config/dotnet-tools.json)"
 # https://learn.microsoft.com/en-us/nuget/api/registration-base-url-resource
 latest_wix="$(curl -sL "$(
 	curl -sL https://api.nuget.org/v3/index.json \
 		| jq -r '.resources[] | select(."@type" == "RegistrationsBaseUrl/3.6.0") | ."@id" + "wix/index.json"')" \
-	| gzip -d \
 	| jq '.items[0].items[].catalogEntry.version | select (. | contains("-") | not)' \
 	| jq -sr '. | last')"
 
