@@ -1,4 +1,4 @@
-use fend_core::{evaluate, Context};
+use fend_core::{Context, evaluate};
 
 #[track_caller]
 fn test_serialization_roundtrip(context: &mut Context) {
@@ -125,10 +125,12 @@ fn two_pi() {
 #[test]
 fn pi_to_fraction() {
 	let mut ctx = Context::new();
-	assert!(evaluate("pi to fraction", &mut ctx)
-		.unwrap()
-		.get_main_result()
-		.starts_with("approx."));
+	assert!(
+		evaluate("pi to fraction", &mut ctx)
+			.unwrap()
+			.get_main_result()
+			.starts_with("approx.")
+	);
 }
 
 const DIVISION_BY_ZERO_ERROR: &str = "division by zero";
@@ -391,7 +393,6 @@ fn implicit_lambda_12() {
 }
 
 #[test]
-#[ignore]
 fn implicit_lambda_13() {
 	test_eval("-sqrt 4", "-2");
 }
@@ -572,7 +573,7 @@ fn large_simple_subtraction_2() {
 
 #[test]
 fn sqrt_half() {
-	test_eval("sqrt (1/2)", "approx. 0.7071067814");
+	test_eval("sqrt (1/2)", "approx. 0.7071067811");
 }
 
 #[test]
@@ -587,7 +588,7 @@ fn sqrt_1() {
 
 #[test]
 fn sqrt_2() {
-	test_eval("sqrt 2", "approx. 1.4142135619");
+	test_eval("sqrt 2", "approx. 1.4142135623");
 }
 
 #[test]
@@ -1201,7 +1202,7 @@ fn powers_15() {
 
 #[test]
 fn powers_16() {
-	test_eval("4^(1/4)", "approx. 1.4142135619");
+	test_eval("4^(1/4)", "approx. 1.4142135623");
 }
 
 #[test]
@@ -1213,7 +1214,7 @@ fn powers_17() {
 fn powers_18() {
 	test_eval(
 		"5.2*10^15*300^(3/2)",
-		"approx. 27019992598076723515.9873962402",
+		"approx. 27019992598074485776.9266786817",
 	);
 }
 
@@ -2500,7 +2501,7 @@ fn abs_2_i() {
 
 #[test]
 fn abs_1_plus_i() {
-	test_eval("abs (1 + i)", "approx. 1.4142135619");
+	test_eval("abs (1 + i)", "approx. 1.4142135623");
 }
 
 #[test]
@@ -5397,7 +5398,7 @@ fn day_of_week_type_name() {
 
 #[test]
 fn phi() {
-	test_eval("phi", "approx. 1.6180339886");
+	test_eval("phi", "approx. 1.6180339887");
 }
 
 #[test]
@@ -6037,9 +6038,15 @@ fn test_words() {
 		"one million two hundred and thirty-four thousand five hundred and sixty-seven",
 	);
 	test_eval_simple("1000000000 to words", "one billion");
-	test_eval_simple("9876543210 to words", "nine billion eight hundred and seventy-six million five hundred and forty-three thousand two hundred and ten");
+	test_eval_simple(
+		"9876543210 to words",
+		"nine billion eight hundred and seventy-six million five hundred and forty-three thousand two hundred and ten",
+	);
 	test_eval_simple("1000000000000 to words", "one trillion");
-	test_eval_simple("1234567890123456 to words", "one quadrillion two hundred and thirty-four trillion five hundred and sixty-seven billion eight hundred and ninety million one hundred and twenty-three thousand four hundred and fifty-six");
+	test_eval_simple(
+		"1234567890123456 to words",
+		"one quadrillion two hundred and thirty-four trillion five hundred and sixty-seven billion eight hundred and ninety million one hundred and twenty-three thousand four hundred and fifty-six",
+	);
 	test_eval_simple("1000000000000000000000 to words", "one sextillion");
 	test_eval_simple("1000000000000000000000000 to words", "one septillion");
 }
@@ -6084,7 +6091,12 @@ fn kilopond() {
 	test_eval("kilopond to N", "9.80665 N");
 	test_eval("megapond to N", "9806.65 N");
 	test_eval("gf to N", "0.00980665 N");
-	expect_error("GF to N", Some("cannot convert from GF to N: units 'ampere^2 second^4 kilogram^-1 meter^-2' and 'kilogram meter / second^2' are incompatible"));
+	expect_error(
+		"GF to N",
+		Some(
+			"cannot convert from GF to N: units 'ampere^2 second^4 kilogram^-1 meter^-2' and 'kilogram meter / second^2' are incompatible",
+		),
+	);
 }
 
 #[derive(Debug)]
