@@ -5,6 +5,7 @@ import globals from 'globals';
 import reactHooks from 'eslint-plugin-react-hooks';
 import reactRefresh from 'eslint-plugin-react-refresh';
 import tseslint from 'typescript-eslint';
+import reactCompiler from 'eslint-plugin-react-compiler';
 
 /** @type any */
 const reactHooksPlugin = reactHooks;
@@ -12,12 +13,15 @@ const reactHooksPlugin = reactHooks;
 const reactHooksRules = reactHooks.configs.recommended.rules;
 
 export default tseslint.config(
-	{ ignores: ['dist'] },
+	js.configs.recommended,
+	...tseslint.configs.strictTypeChecked,
+	reactRefresh.configs.vite,
+	{ ignores: ['dist', 'cloudflare', 'eslint.config.js'] },
 	{
-		extends: [js.configs.recommended, ...tseslint.configs.strictTypeChecked],
 		files: ['**/*.{ts,tsx}'],
+	},
+	{
 		languageOptions: {
-			ecmaVersion: 2020,
 			globals: globals.browser,
 			parserOptions: {
 				projectService: true,
@@ -26,11 +30,12 @@ export default tseslint.config(
 		},
 		plugins: {
 			'react-hooks': reactHooksPlugin,
-			'react-refresh': reactRefresh,
+			'react-compiler': reactCompiler,
 		},
 		rules: {
 			...reactHooksRules,
-			'react-refresh/only-export-components': ['warn', { allowConstantExport: true }],
+			'react-compiler/react-compiler': 'error',
+			'@typescript-eslint/promise-function-async': 'error',
 		},
 	},
 );
